## Notice

This project has been merged with [ship-traffic-gen](https://github.com/dnv-opensource/ship-traffic-generator). The python types that were part of this package are now maintained in [types.py](https://github.com/dnv-opensource/ship-traffic-generator/blob/main/src/trafficgen/types.py) as part of ship-traffic-gen.



